@@ -5,8 +5,8 @@
    This program displays raw metadata for all raw photo formats.
    It is free for all uses.
 
-   $Revision: 1.65 $
-   $Date: 2007/05/15 06:16:12 $
+   $Revision: 1.66 $
+   $Date: 2008/01/19 06:01:47 $
  */
 
 #include <stdio.h>
@@ -368,6 +368,11 @@ int parse_tiff_ifd (int base, int level)
 	fseek (ifp, get4()+base, SEEK_SET);
 	parse_exif (base, level+1);
 	break;
+      case 34853:
+	puts("GPS data:");
+	fseek (ifp, get4()+base, SEEK_SET);
+	parse_tiff_ifd (base, level+1);
+	break;
       case 50459:
 	i = order;
 	save2 = ftell(ifp);
